@@ -66,16 +66,23 @@ class FullNameMixin:
         if self.denominazione is None:
             if self.nome is None and self.cognome is None:
                 validation.add_error(
-                        (self._meta["nome"], self._meta["cognome"], self._meta["denominazione"]),
-                        "nome and cognome, or denominazione, must be set")
+                    (
+                        self._meta["nome"],
+                        self._meta["cognome"],
+                        self._meta["denominazione"],
+                    ),
+                    "nome and cognome, or denominazione, must be set",
+                )
             elif self.nome is None:
                 validation.add_error(
-                        self._meta["nome"],
-                        "nome and cognome must both be set if denominazione is empty")
+                    self._meta["nome"],
+                    "nome and cognome must both be set if denominazione is empty",
+                )
             elif self.cognome is None:
                 validation.add_error(
-                        self._meta["cognome"],
-                        "nome and cognome must both be set if denominazione is empty")
+                    self._meta["cognome"],
+                    "nome and cognome must both be set if denominazione is empty",
+                )
         else:
             should_not_be_set = []
             if self.nome is not None:
@@ -84,9 +91,11 @@ class FullNameMixin:
                 should_not_be_set.append(self._meta["cognome"])
             if should_not_be_set:
                 validation.add_error(
-                        should_not_be_set,
-                        "{} must not be set if denominazione is not empty".format(
-                            " and ".join(x.name for x in should_not_be_set)))
+                    should_not_be_set,
+                    "{} must not be set if denominazione is not empty".format(
+                        " and ".join(x.name for x in should_not_be_set)
+                    ),
+                )
 
 
 @export
@@ -116,16 +125,21 @@ class DatiTrasmissione(models.Model):
     id_trasmittente = IdTrasmittente
     progressivo_invio = fields.ProgressivoInvioField()
     formato_trasmissione = fields.StringField(length=5, choices=("FPR12", "FPA12"))
-    codice_destinatario = fields.StringField(null=True, min_length=6, max_length=7, default="0000000")
+    codice_destinatario = fields.StringField(
+        null=True, min_length=6, max_length=7, default="0000000"
+    )
     contatti_trasmittente = fields.ModelField(ContattiTrasmittente, null=True)
-    pec_destinatario = fields.StringField(null=True, min_length=8, max_length=256, xmltag="PECDestinatario")
+    pec_destinatario = fields.StringField(
+        null=True, min_length=8, max_length=256, xmltag="PECDestinatario"
+    )
 
     def validate_model(self, validation):
         super().validate_model(validation)
         if self.codice_destinatario is None and self.pec_destinatario is None:
             validation.add_error(
-                    (self._meta["codice_destinatario"], self._meta["pec_destinatario"]),
-                    "one of codice_destinatario or pec_destinatario must be set")
+                (self._meta["codice_destinatario"], self._meta["pec_destinatario"]),
+                "one of codice_destinatario or pec_destinatario must be set",
+            )
 
         # Se la fattura deve essere recapitata ad un soggetto che intende
         # ricevere le fatture elettroniche attraverso il canale PEC, il campo
@@ -134,28 +148,35 @@ class DatiTrasmissione(models.Model):
 
         if self.pec_destinatario is None and self.codice_destinatario == "0000000":
             validation.add_error(
-                    (self._meta["codice_destinatario"], self._meta["pec_destinatario"]),
-                    "pec_destinatario has no value while codice_destinatario has value 0000000",
-                    code="00426")
+                (self._meta["codice_destinatario"], self._meta["pec_destinatario"]),
+                "pec_destinatario has no value while codice_destinatario has value 0000000",
+                code="00426",
+            )
 
-        if (self.pec_destinatario is not None and self.codice_destinatario is
-                not None and self.codice_destinatario != "0000000"):
+        if (
+            self.pec_destinatario is not None
+            and self.codice_destinatario is not None
+            and self.codice_destinatario != "0000000"
+        ):
             validation.add_error(
-                    (self._meta["codice_destinatario"], self._meta["pec_destinatario"]),
-                    "pec_destinatario has value while codice_destinatario has value 0000000",
-                    code="00426")
+                (self._meta["codice_destinatario"], self._meta["pec_destinatario"]),
+                "pec_destinatario has value while codice_destinatario has value 0000000",
+                code="00426",
+            )
 
         if self.formato_trasmissione == "FPA12" and len(self.codice_destinatario) == 7:
             validation.add_error(
-                    self._meta["codice_destinatario"],
-                    "codice_destinatario has 7 characters on a Fattura PA",
-                    code="00427")
+                self._meta["codice_destinatario"],
+                "codice_destinatario has 7 characters on a Fattura PA",
+                code="00427",
+            )
 
         if self.formato_trasmissione == "FPR12" and len(self.codice_destinatario) == 6:
             validation.add_error(
-                    self._meta["codice_destinatario"],
-                    "codice_destinatario has 6 characters on a Fattura Privati",
-                    code="00427")
+                self._meta["codice_destinatario"],
+                "codice_destinatario has 6 characters on a Fattura Privati",
+                code="00427",
+            )
 
 
 @export
@@ -164,7 +185,9 @@ class Anagrafica(FullNameMixin, models.Model):
     nome = fields.StringField(max_length=60, null=True)
     cognome = fields.StringField(max_length=60, null=True)
     titolo = fields.StringField(min_length=2, max_length=10, null=True)
-    cod_eori = fields.StringField(xmltag="CodEORI", min_length=13, max_length=17, null=True)
+    cod_eori = fields.StringField(
+        xmltag="CodEORI", min_length=13, max_length=17, null=True
+    )
 
 
 @export
@@ -177,8 +200,7 @@ class DatiAnagraficiCedentePrestatore(models.Model):
     provincia_albo = fields.StringField(length=2, null=True)
     numero_iscrizione_albo = fields.StringField(max_length=60, null=True)
     data_iscrizione_albo = fields.DateField(null=True)
-    regime_fiscale = fields.StringField(
-            length=4, choices=consts.REGIME_FISCALE)
+    regime_fiscale = fields.StringField(length=4, choices=consts.REGIME_FISCALE)
 
 
 @export
@@ -238,9 +260,10 @@ class DatiAnagraficiCessionarioCommittente(models.Model):
         super().validate_model(validation)
         if self.id_fiscale_iva is None and self.codice_fiscale is None:
             validation.add_error(
-                    (self._meta["id_fiscale_iva"], self._meta["codice_fiscale"]),
-                    "at least one of id_fiscale_iva and codice_fiscale needs to have a value",
-                    code="00417")
+                (self._meta["id_fiscale_iva"], self._meta["codice_fiscale"]),
+                "at least one of id_fiscale_iva and codice_fiscale needs to have a value",
+                code="00417",
+            )
 
 
 @export
@@ -290,9 +313,13 @@ class TerzoIntermediarioOSoggettoEmittente(models.Model):
 class FatturaElettronicaHeader(models.Model):
     dati_trasmissione = DatiTrasmissione
     cedente_prestatore = CedentePrestatore
-    rappresentante_fiscale = models.ModelField(RappresentanteFiscaleCedentePrestatore, null=True)
+    rappresentante_fiscale = models.ModelField(
+        RappresentanteFiscaleCedentePrestatore, null=True
+    )
     cessionario_committente = CessionarioCommittente
-    terzo_intermediario_o_soggetto_emittente = models.ModelField(TerzoIntermediarioOSoggettoEmittente, null=True)
+    terzo_intermediario_o_soggetto_emittente = models.ModelField(
+        TerzoIntermediarioOSoggettoEmittente, null=True
+    )
     soggetto_emittente = fields.StringField(length=2, choices=("CC", "TZ"), null=True)
 
 
@@ -318,17 +345,25 @@ class DatiCassaPrevidenziale(models.Model):
     imponibile_cassa = fields.DecimalField(max_length=15)
     aliquota_iva = fields.DecimalField(max_length=6, xmltag="AliquotaIVA")
     ritenuta = fields.StringField(length=2, choices=("SI",), null=True)
-    natura = fields.StringField(min_length=2, max_length=4, choices=consts.NATURA_IVA, null=True)
+    natura = fields.StringField(
+        min_length=2, max_length=4, choices=consts.NATURA_IVA, null=True
+    )
     riferimento_amministrazione = fields.StringField(max_length=20, null=True)
 
     def validate_model(self, validation):
         super().validate_model(validation)
         if self.aliquota_iva == 0 and self.natura is None:
             validation.add_error(
-                self._meta["natura"], "field is empty while aliquota_iva is zero", code="00413")
+                self._meta["natura"],
+                "field is empty while aliquota_iva is zero",
+                code="00413",
+            )
         if self.aliquota_iva != 0 and self.natura is not None:
             validation.add_error(
-                self._meta["natura"], "field has value while aliquota_iva is not zero", code="00414")
+                self._meta["natura"],
+                "field has value while aliquota_iva is not zero",
+                code="00414",
+            )
 
 
 @export
@@ -344,7 +379,7 @@ class DatiGeneraliDocumento(models.Model):
     divisa = fields.StringField()
     data = fields.DateField()
     numero = fields.StringField(max_length=20)
-    dati_ritenuta = fields.ModelField(DatiRitenuta, null=True)
+    dati_ritenuta = fields.ModelListField(DatiRitenuta, null=True)
     dati_bollo = fields.ModelField(DatiBollo, null=True)
     dati_cassa_previdenziale = fields.ModelListField(DatiCassaPrevidenziale, null=True)
     sconto_maggiorazione = fields.ModelListField(ScontoMaggiorazione, null=True)
@@ -364,18 +399,24 @@ class DatiGeneraliDocumento(models.Model):
 
         if has_dati_cassa_previdenziale_ritenuta and not self.dati_ritenuta.has_value():
             validation.add_error(
-                self._meta["ritenuta"], "field empty when dati_cassa_previdenziale.ritenuta is SI", code="00415")
+                self._meta["ritenuta"],
+                "field empty when dati_cassa_previdenziale.ritenuta is SI",
+                code="00415",
+            )
 
         if self.numero is None or not re.search(r"\d", self.numero):
             validation.add_error(
-                self._meta["numero"], "numero must contain at least one number", code="00425")
+                self._meta["numero"],
+                "numero must contain at least one number",
+                code="00425",
+            )
 
 
 @export
 class AltriDatiGestionali(models.Model):
     tipo_dato = fields.StringField(max_length=10)
     riferimento_testo = fields.StringField(max_length=60, null=True)
-    riferimento_numero = fields.DecimalField(max_length=21, null=True)
+    riferimento_numero = fields.DecimalField(max_length=21, decimals=(2, 8), null=True)
     riferimento_data = fields.DateField(null=True)
 
 
@@ -388,34 +429,48 @@ class CodiceArticolo(models.Model):
 @export
 class DettaglioLinee(models.Model):
     numero_linea = fields.IntegerField(max_length=4)
-    tipo_cessione_prestazione = fields.StringField(length=2, choices=("SC", "PR", "AB", "AC"), null=True)
+    tipo_cessione_prestazione = fields.StringField(
+        length=2, choices=("SC", "PR", "AB", "AC"), null=True
+    )
     codice_articolo = fields.ModelListField(CodiceArticolo, null=True)
     descrizione = fields.StringField(max_length=1000)
-    quantita = fields.DecimalField(max_length=21, decimals=2, null=True)
+    quantita = fields.DecimalField(max_length=21, decimals=(2, 8), null=True)
     unita_misura = fields.StringField(max_length=10, null=True)
     data_inizio_periodo = fields.DateField(null=True)
     data_fine_periodo = fields.DateField(null=True)
-    prezzo_unitario = fields.DecimalField(max_length=21, decimals=3)
+    prezzo_unitario = fields.DecimalField(max_length=21, decimals=(2, 8))
     sconto_maggiorazione = fields.ModelListField(ScontoMaggiorazione, null=True)
-    prezzo_totale = fields.DecimalField(max_length=21)
+    prezzo_totale = fields.DecimalField(max_length=21, decimals=(2, 8))
     aliquota_iva = fields.DecimalField(xmltag="AliquotaIVA", max_length=6)
     ritenuta = fields.StringField(length=2, choices=("SI",), null=True)
-    natura = fields.StringField(min_length=2, max_length=4, null=True, choices=consts.NATURA_IVA)
+    natura = fields.StringField(
+        min_length=2, max_length=4, null=True, choices=consts.NATURA_IVA
+    )
     riferimento_amministrazione = fields.StringField(max_length=20, null=True)
     altri_dati_gestionali = fields.ModelListField(AltriDatiGestionali, null=True)
 
     def validate_model(self, validation):
         super().validate_model(validation)
         if self.quantita is None and self.unita_misura is not None:
-            validation.add_error(self._meta["quantita"], "field must be present when unita_misura is set")
+            validation.add_error(
+                self._meta["quantita"], "field must be present when unita_misura is set"
+            )
         if self.quantita is not None and self.unita_misura is None:
-            validation.add_error(self._meta["unita_misura"], "field must be present when quantita is set")
+            validation.add_error(
+                self._meta["unita_misura"], "field must be present when quantita is set"
+            )
         if self.aliquota_iva == 0 and self.natura is None:
             validation.add_error(
-                self._meta["natura"], "natura non presente a fronte di aliquota_iva pari a zero", code="00400")
+                self._meta["natura"],
+                "natura non presente a fronte di aliquota_iva pari a zero",
+                code="00400",
+            )
         if self.aliquota_iva != 0 and self.natura is not None:
             validation.add_error(
-                self._meta["natura"], "natura presente a fronte di aliquota_iva diversa da zero", code="00401")
+                self._meta["natura"],
+                "natura presente a fronte di aliquota_iva diversa da zero",
+                code="00401",
+            )
 
     def autofill_prezzo_totale(self):
         """
@@ -432,26 +487,36 @@ class DettaglioLinee(models.Model):
 @export
 class DatiRiepilogo(models.Model):
     aliquota_iva = fields.DecimalField(xmltag="AliquotaIVA", max_length=6)
-    natura = fields.StringField(min_length=2, max_length=4, null=True, choices=consts.NATURA_IVA)
+    natura = fields.StringField(
+        min_length=2, max_length=4, null=True, choices=consts.NATURA_IVA
+    )
     spese_accessorie = fields.DecimalField(max_length=15, null=True)
-    arrotondamento = fields.DecimalField(max_length=21, null=True)
+    arrotondamento = fields.DecimalField(max_length=21, decimals=(2, 8), null=True)
     # FIXME: Su questo valore il sistema effettua un controllo per verificare
     # la correttezza del calcolo; per i dettagli sull’algoritmo di calcolo si
     # rimanda al file Elenco controlli versione 1.4 presente sul sito
     # www.fatturapa.gov.it.
     imponibile_importo = fields.DecimalField(max_length=15)
     imposta = fields.DecimalField(max_length=15)
-    esigibilita_iva = fields.StringField(xmltag="EsigibilitaIVA", length=1, choices=("I", "D", "S"), null=True)
+    esigibilita_iva = fields.StringField(
+        xmltag="EsigibilitaIVA", length=1, choices=("I", "D", "S"), null=True
+    )
     riferimento_normativo = fields.StringField(max_length=100, null=True)
 
     def validate_model(self, validation):
         super().validate_model(validation)
         if self.aliquota_iva == 0 and self.natura is None:
             validation.add_error(
-                self._meta["natura"], "field is empty while aliquota_iva is zero", code="00429")
+                self._meta["natura"],
+                "field is empty while aliquota_iva is zero",
+                code="00429",
+            )
         if self.aliquota_iva != 0 and self.natura is not None:
             validation.add_error(
-                self._meta["natura"], "field has value while aliquota_iva is not zero", code="00430")
+                self._meta["natura"],
+                "field has value while aliquota_iva is not zero",
+                code="00430",
+            )
 
 
 @export
@@ -498,14 +563,21 @@ class DatiBeniServizi(models.Model):
             imponibile = sum(linea.prezzo_totale for linea in linee)
             imposta = imponibile * aliquota / 100
             self.dati_riepilogo.append(
-                    DatiRiepilogo(
-                        aliquota_iva=aliquota, imponibile_importo=imponibile,
-                        imposta=imposta, esigibilita_iva="I", natura=natura))
+                DatiRiepilogo(
+                    aliquota_iva=aliquota,
+                    imponibile_importo=imponibile,
+                    imposta=imposta,
+                    esigibilita_iva="I",
+                    natura=natura,
+                )
+            )
 
 
 @export
 class DatiDocumentiCorrelati(models.Model):
-    riferimento_numero_linea = fields.ListField(fields.IntegerField(max_length=4), null=True)
+    riferimento_numero_linea = fields.ListField(
+        fields.IntegerField(max_length=4), null=True
+    )
     id_documento = fields.StringField(max_length=20)
     data = fields.DateField(null=True)
     num_item = fields.StringField(max_length=20, null=True)
@@ -574,7 +646,9 @@ class DatiDDT(models.Model):
     __xmltag__ = "DatiDDT"
     numero_ddt = fields.StringField(max_length=20, xmltag="NumeroDDT")
     data_ddt = fields.DateField(xmltag="DataDDT")
-    riferimento_numero_linea = fields.ListField(fields.IntegerField(max_length=4), null=True)
+    riferimento_numero_linea = fields.ListField(
+        fields.IntegerField(max_length=4), null=True
+    )
 
 
 @export
@@ -598,13 +672,19 @@ class DatiGenerali(models.Model):
 
     def validate_model(self, validation):
         super().validate_model(validation)
-        dfc_dates = [x.data for x in self.dati_fatture_collegate if x.data is not None]
-        if dfc_dates and self.dati_generali_documento.data < min(dfc_dates):
-            validation.add_error(
-                (self.dati_fatture_collegate._meta["data"],
-                 self.dati_generali_documento._meta["data"]),
-                "dati_generali_documento.data is earlier than dati_fatture_collegate.data",
-                code="00418")
+        for idx, dfc in enumerate(self.dati_fatture_collegate):
+            if dfc.data is None:
+                continue
+            if self.dati_generali_documento.data < dfc.data:
+                validation.add_error(
+                    (
+                        dfc._meta["data"],
+                        self.dati_generali_documento._meta["data"],
+                    ),
+                    f"dati_generali_documento[{idx}].data"
+                    " is earlier than dati_fatture_collegate.data",
+                    code="00418",
+                )
 
 
 @export
@@ -618,7 +698,9 @@ class DettaglioPagamento(models.Model):
     cod_ufficio_postale = fields.StringField(max_length=20, null=True)
     cognome_quietanzante = fields.StringField(max_length=60, null=True)
     nome_quietanzante = fields.StringField(max_length=60, null=True)
-    cf_quietanzante = fields.StringField(max_length=16, null=True, xmltag="CFQuietanzante")
+    cf_quietanzante = fields.StringField(
+        max_length=16, null=True, xmltag="CFQuietanzante"
+    )
     titolo_quietanzante = fields.StringField(min_length=2, max_length=10, null=True)
     istituto_finanziario = fields.StringField(max_length=80, null=True)
     iban = fields.StringField(min_length=15, max_length=34, null=True, xmltag="IBAN")
@@ -634,7 +716,9 @@ class DettaglioPagamento(models.Model):
 
 @export
 class DatiPagamento(models.Model):
-    condizioni_pagamento = fields.StringField(length=4, choices=("TP01", "TP02", "TP03"))
+    condizioni_pagamento = fields.StringField(
+        length=4, choices=("TP01", "TP02", "TP03")
+    )
     dettaglio_pagamento = fields.ModelListField(DettaglioPagamento)
 
 
@@ -674,7 +758,10 @@ class FatturaElettronicaBody(models.Model):
         importo_totale_documento yourself, or better, extend this function and
         submit a pull request.
         """
-        totale = sum(r.imponibile_importo + r.imposta for r in self.dati_beni_servizi.dati_riepilogo)
+        totale = sum(
+            r.imponibile_importo + r.imposta
+            for r in self.dati_beni_servizi.dati_riepilogo
+        )
         self.dati_generali.dati_generali_documento.importo_totale_documento = totale
 
     def validate_model(self, validation):
@@ -688,7 +775,10 @@ class FatturaElettronicaBody(models.Model):
             if dl.aliquota_iva is not None:
                 has_aliquote_iva = True
 
-        if has_ritenute and not self.dati_generali.dati_generali_documento.dati_ritenuta.has_value():
+        if (
+            has_ritenute
+            and not self.dati_generali.dati_generali_documento.dati_ritenuta.has_value()
+        ):
             validation.add_error(
                 self.dati_generali.dati_generali_documento._meta["dati_ritenuta"],
                 "field empty while at least one of dati_beni_servizi.dettaglio_linee.ritenuta is SI",
@@ -701,10 +791,11 @@ class FatturaElettronicaBody(models.Model):
 
         if not self.dati_beni_servizi.dati_riepilogo and has_aliquote_iva:
             validation.add_error(
-                    self.dati_beni_servizi._meta["dati_riepilogo"],
-                    "dati_riepilogo is empty while there is at least an aliquota_iva"
-                    " in dettaglio_linee or dati_cassa_previdenziale",
-                    code="00419")
+                self.dati_beni_servizi._meta["dati_riepilogo"],
+                "dati_riepilogo is empty while there is at least an aliquota_iva"
+                " in dettaglio_linee or dati_cassa_previdenziale",
+                code="00419",
+            )
 
 
 @export
@@ -718,7 +809,9 @@ class Fattura(models.Model):
 
     def __init__(self, *args, **kw):
         super().__init__(*args, **kw)
-        self.fattura_elettronica_header.dati_trasmissione.formato_trasmissione = self.get_versione()
+        self.fattura_elettronica_header.dati_trasmissione.formato_trasmissione = (
+            self.get_versione()
+        )
 
     def get_versione(self):
         return None
@@ -728,11 +821,17 @@ class Fattura(models.Model):
 
     def validate_model(self, validation):
         super().validate_model(validation)
-        if self.get_versione() != self.fattura_elettronica_header.dati_trasmissione.formato_trasmissione:
+        if (
+            self.get_versione()
+            != self.fattura_elettronica_header.dati_trasmissione.formato_trasmissione
+        ):
             validation.add_error(
-                    self.fattura_elettronica_header.dati_trasmissione._meta["formato_trasmissione"],
-                    "formato_trasmissione should be {}".format(self.get_versione()),
-                    code="00428")
+                self.fattura_elettronica_header.dati_trasmissione._meta[
+                    "formato_trasmissione"
+                ],
+                "formato_trasmissione should be {}".format(self.get_versione()),
+                code="00428",
+            )
 
     def to_xml(self, builder):
         with builder.element(self.get_xmltag(), **self.get_xmlattrs()) as b:
@@ -744,12 +843,16 @@ class Fattura(models.Model):
         """
         Build and return an ElementTree with the fattura in XML format
         """
-        self.fattura_elettronica_header.dati_trasmissione.formato_trasmissione = self.get_versione()
+        self.fattura_elettronica_header.dati_trasmissione.formato_trasmissione = (
+            self.get_versione()
+        )
         if lxml:
             from a38.builder import LXMLBuilder
+
             builder = LXMLBuilder()
         else:
             from a38.builder import Builder
+
             builder = Builder()
         builder.default_namespace = NS
         self.to_xml(builder)
@@ -758,10 +861,16 @@ class Fattura(models.Model):
     def from_etree(self, el):
         versione = el.attrib.get("versione", None)
         if versione is None:
-            raise RuntimeError("root element {} misses attribute 'versione'".format(el.tag))
+            raise RuntimeError(
+                "root element {} misses attribute 'versione'".format(el.tag)
+            )
 
         if versione != self.get_versione():
-            raise RuntimeError("root element versione is {} instead of {}".format(versione, self.get_versione()))
+            raise RuntimeError(
+                "root element versione is {} instead of {}".format(
+                    versione, self.get_versione()
+                )
+            )
 
         return super().from_etree(el)
 
@@ -771,6 +880,7 @@ class FatturaPrivati12(Fattura):
     """
     Fattura privati 1.2
     """
+
     def get_versione(self):
         return "FPR12"
 
@@ -780,16 +890,20 @@ class FatturaPA12(Fattura):
     """
     Fattura PA 1.2
     """
+
     def get_versione(self):
         return "FPA12"
 
 
 @export
-def auto_from_etree(root: ET.ElementTree) -> Union[Fattura, FatturaElettronicaSemplificata]:
+def auto_from_etree(
+    root: ET.ElementTree,
+) -> Union[Fattura, FatturaElettronicaSemplificata]:
     """
     Instantiate a Fattura or FatturaElettronicaSemplificata from a parsed XML
     """
     from .fattura_semplificata import NS10, FatturaElettronicaSemplificata
+
     tagname_ordinaria = "{{{}}}FatturaElettronica".format(NS)
     tagname_semplificata = "{{{}}}FatturaElettronicaSemplificata".format(NS10)
 
@@ -797,7 +911,9 @@ def auto_from_etree(root: ET.ElementTree) -> Union[Fattura, FatturaElettronicaSe
 
     if root.tag == tagname_ordinaria:
         if versione is None:
-            raise RuntimeError("root element {} misses attribute 'versione'".format(root.tag))
+            raise RuntimeError(
+                "root element {} misses attribute 'versione'".format(root.tag)
+            )
         if versione == "FPR12":
             res = FatturaPrivati12()
         elif versione == "FPA12":
@@ -806,30 +922,42 @@ def auto_from_etree(root: ET.ElementTree) -> Union[Fattura, FatturaElettronicaSe
             raise RuntimeError("unsupported versione {}".format(versione))
     elif root.tag == tagname_semplificata:
         if versione is None:
-            raise RuntimeError("root element {} misses attribute 'versione'".format(root.tag))
+            raise RuntimeError(
+                "root element {} misses attribute 'versione'".format(root.tag)
+            )
         if versione == "FSM10":
             res = FatturaElettronicaSemplificata()
         else:
             raise RuntimeError("unsupported versione {}".format(versione))
     else:
-        raise RuntimeError("Root element {} is neither {} nor {}".format(
-            root.tag, tagname_ordinaria, tagname_semplificata))
+        raise RuntimeError(
+            "Root element {} is neither {} nor {}".format(
+                root.tag, tagname_ordinaria, tagname_semplificata
+            )
+        )
 
     res.from_etree(root)
     return res
 
 
 @export
-def auto_from_dict(data: Dict[str, Any]) -> Union[Fattura, FatturaElettronicaSemplificata]:
+def auto_from_dict(
+    data: Dict[str, Any]
+) -> Union[Fattura, FatturaElettronicaSemplificata]:
     """
     Given the equivalent of a Fattura.to_jsonable() data structure,
     reconstruct the fattura
     """
     from .fattura_semplificata import FatturaElettronicaSemplificata
+
     try:
-        formato = data["fattura_elettronica_header"]["dati_trasmissione"]["formato_trasmissione"]
+        formato = data["fattura_elettronica_header"]["dati_trasmissione"][
+            "formato_trasmissione"
+        ]
     except KeyError:
-        raise RuntimeError("fattura_elettronica_header.dati_trasmissione.formato_trasmissione not found in input")
+        raise RuntimeError(
+            "fattura_elettronica_header.dati_trasmissione.formato_trasmissione not found in input"
+        )
 
     if formato == "FPR12":
         return FatturaPrivati12(**data)
